API documentation
=================

 .. toctree::
    :maxdepth: 2

    demo_functions
    InputHipims
    OutputHipims
    Boundary
    Landcover
    Raster
    Rainfall
    Summary
    rainfall_processing
    grid_show
    spatial_analysis
    indep_functions